"""Модуль конфигурации GLT CLI."""

import logging
import sys
from typing import Optional

from rich.console import Console
from rich.logging import RichHandler

console = Console()


def setup_logging(
    verbose: bool = False,
    log_level: Optional[str] = None,
) -> None:
    """Настраивает логирование с использованием Rich.
    
    Args:
        verbose: Включить подробный вывод
        log_level: Уровень логирования (DEBUG, INFO, WARNING, ERROR)
    """
    if log_level is None:
        log_level = "DEBUG" if verbose else "INFO"
    
    # Настраиваем форматтер для Rich
    logging.basicConfig(
        level=getattr(logging, log_level.upper()),
        format="%(message)s",
        datefmt="[%X]",
        handlers=[
            RichHandler(
                console=console,
                rich_tracebacks=True,
                markup=True,
                show_path=verbose,
            )
        ],
    )
    
    # Устанавливаем уровень для сторонних библиотек
    logging.getLogger("urllib3").setLevel(logging.WARNING)
    logging.getLogger("requests").setLevel(logging.WARNING)
    logging.getLogger("ipfshttpclient").setLevel(logging.WARNING)
    
    if verbose:
        console.print(f"[dim]🔧 Уровень логирования: {log_level}[/dim]") 