"""Тесты для моделей данных."""

import pytest
from pydantic import ValidationError

import sys
import os
sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', 'glt_cli'))
from models import GLTConfig, MetaInfo, Stack


class TestMetaInfo:
    """Тесты для MetaInfo."""
    
    def test_valid_meta_info(self):
        """Тест валидной метаинформации."""
        meta = MetaInfo(
            name="test.module",
            wave="Æ3",
            owner="@test_user",
            visibility="private"
        )
        
        assert meta.name == "test.module"
        assert meta.wave == "Æ3"
        assert meta.owner == "@test_user"
        assert meta.visibility == "private"
    
    def test_invalid_visibility(self):
        """Тест невалидной видимости."""
        with pytest.raises(ValidationError):
            MetaInfo(
                name="test.module",
                wave="Æ3",
                owner="@test_user",
                visibility="invalid"
            )


class TestStack:
    """Тесты для Stack."""
    
    def test_valid_stack(self):
        """Тест валидного стека."""
        stack = Stack(
            runtime="python:3.12-slim",
            deps=["typer[all]>=0.9", "pydantic>=2"],
            dev_deps=["pytest", "mypy"]
        )
        
        assert stack.runtime == "python:3.12-slim"
        assert len(stack.deps) == 2
        assert len(stack.dev_deps) == 2


class TestGLTConfig:
    """Тесты для GLTConfig."""
    
    def test_valid_config(self):
        """Тест валидной конфигурации."""
        config = GLTConfig(
            version="0.6",
            meta=MetaInfo(
                name="test.module",
                wave="Æ3",
                owner="@test_user",
                visibility="private"
            ),
            stack=Stack(
                runtime="python:3.12-slim",
                deps=["typer[all]>=0.9"],
                dev_deps=["pytest"]
            )
        )
        
        assert config.version == "0.6"
        assert config.meta.name == "test.module"
        assert config.stack.runtime == "python:3.12-slim"
    
    def test_invalid_version(self):
        """Тест невалидной версии."""
        with pytest.raises(ValidationError):
            GLTConfig(
                version="invalid",
                meta=MetaInfo(
                    name="test.module",
                    wave="Æ3",
                    owner="@test_user",
                    visibility="private"
                ),
                stack=Stack(
                    runtime="python:3.12-slim",
                    deps=[],
                    dev_deps=[]
                )
            )
    
    def test_missing_required_fields(self):
        """Тест отсутствующих обязательных полей."""
        with pytest.raises(ValidationError):
            GLTConfig(
                version="0.6",
                # Отсутствует meta
                stack=Stack(
                    runtime="python:3.12-slim",
                    deps=[],
                    dev_deps=[]
                )
            ) 